<?xml version="1.0" ?><!DOCTYPE TS><TS language="ia" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 es software libere, ma su developpamento exige un tempore preciose.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;Dona&lt;/a&gt;, per favor, pro supportar le developpamento continue de %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Liberate sub &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Clauder</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Lo que tu sempre ha volite cognoscer super %1 e nunquam osava demandar lo</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Tu pote tamben voler essayar mi altere applicationes:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, un application de YouTube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, un reproductor de musica de YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traduce %1 in tu lingua materne per usar %2</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Comprar in %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Lege plus</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Lege plus</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Retro</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Ir retro</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Benvenite a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 besonia scannar tu collection de musica.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancellar</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Usar le collection de iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Usar %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Seliger un dossier...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 connectara al servicios web de Last.fm web e passara nomines de artista e titulos de album pro cercar copertas, biographias e multe plus.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Si tu ha anxietate de intimitate super isto, tu pote quitar ora.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Ubi se trova tu collection musical?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Selige le localisation de tu collection musical</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Localisa tu collection</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Mundar</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 es scannante tu collection musical.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 es usante &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; pro catalogar tu musica.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Vade sasir un caffe</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <source>Please license %1</source>
        <translation>Per favor, licentia %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Iste demo ha expirate</translation>
    </message>
    <message>
        <source>This demo will expire in %1 days.</source>
        <translation>Iste demo expirara in %1 dies.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Al comprar le version complete, tu va supportar tamben le dur labor que io habeva pro crear %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Usar Demo</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Procura le version complete</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>Le version complete permitte que tu reguarda videos, adde plus %1 tracias al lista de reproduction e ascolta tu musica sin interruptiones.</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Lassa cader hic pro adjunger al lista de reproduction</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Artistas</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albums</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Dossiers</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reproducer</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducer/Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppar</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Stoppar le reproduction post le tracia actual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Proxime tracia</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Previe tracia</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Augmentar le sono</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Diminuer le sono</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mute</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Cerca in avante</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Cerca in retro</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Retro</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Vader al vista previe</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Monstrar information super le tracia actual</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>P&amp;revie</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Vader retro al previe tracia</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>Pro&amp;xime</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Saltar al proxime tracia</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Re&amp;producer</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Initiar le reproduction</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Schermo plen</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Vader a schermo plen</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Remover le tracias seligite del lista de reproduction</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover &amp;in alto</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Mover in alto le tracias seligite in le lista de reproduction</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover a &amp;basso</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Mover a basso le tracias seligite in le lista de reproduction</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitar</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Adeo</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Cambiar le dossier del collection...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Selige un differente dossier de collection musical</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sito &amp;web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 in le web</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Facer un &amp;donation</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Supporta le developpamento continue de %1, per favor</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Super</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info super %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Mundar</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Remover tote le tracias del lista de reproduction</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Rearrangiar</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Modo aleatori del lista de reproduction</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Repeter</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Sona le prime canto de novo, post haber sonate tote le alteres</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Sin sono</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Application</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Reproduction</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>L&amp;ista de reproduction</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vider</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Adjuta</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Preme %1 pro augmentar le volumine, %2 pro bassar lo</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>A aperir %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>A actualisar le collection...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>A actualisar le collection - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Collection actualisate</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Error fatal: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Quitar le schermo &amp;plen</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempore restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volumine a %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Sin sono</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Con sono</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Procura le version complete</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 version %2 ja es disponibile.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Rememora me plus tarde</translation>
    </message>
    <message>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation>Pro obtener le version actualisate, discarga novemente %1 ab le ligamine que tu recipeva per e-posta e reinstalla lo.</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualisar</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenestra</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Clauder</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Comprar %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Lassa cader le elementos hic</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Fin del lista de reproduction</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Iste es solmente le version demo de %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Isto permitte sonar alcun tracias e, assi, testar le application e vider si illo functiona.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obtener le version complete</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Iste demo es limitate a %1 pistas in le lista de reproduction.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Le lista de reproduction es vacue</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 tracias - Le longor total es %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cercar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>Tu cerca no ha resultatos</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Tracias</translation>
    </message>
</context>
</TS>